@@ -5,10 +5,14 @@ output$network_id <- renderVisNetwork({
   edges <- data.frame(from = trunc(runif(15)*(15-1))+1,
                       to = trunc(runif(15)*(15-1))+1)
   
-  visNetwork(nodes, edges) %>%
+  # visNetwork(nodes, edges, main = "Title", submain = "Subtitle", footer = "footer") %>%
+  #   visExport()
+  
+  visNetwork(nodes, edges, main = "Title", submain = "Subtitle", footer = "footer") %>%
     visExport() %>%
-    visOptions(highlightNearest = TRUE, 
+    visOptions(highlightNearest = TRUE,
                nodesIdSelection = list(enabled = TRUE, selected = "1"))
+  
 })
 
 output$view_id <- renderText({
@@ -17,8 +21,9 @@ output$view_id <- renderText({
 
 output$code_network_id <- renderText({
   '
-  visNetwork(nodes, edges) %>%
-    visOptions(highlightNearest = TRUE, 
+  visNetwork(nodes, edges, main = "Title", submain = "Subtitle", footer = "footer") %>%
+    visExport() %>%
+    visOptions(highlightNearest = TRUE,
       nodesIdSelection = list(enabled = TRUE, selected = "1"))
  '
 })
