@@ -13,6 +13,7 @@ shiny::shinyUI(shiny::navbarPage(
     source("./src/ui/proxy_anim_ui.R", local = TRUE)$value,
     source("./src/ui/proxy_update_ui.R", local = TRUE)$value,
     source("./src/ui/proxy_options_ui.R", local = TRUE)$value,
-    source("./src/ui/proxy_select_ui.R", local = TRUE)$value
+    source("./src/ui/proxy_select_ui.R", local = TRUE)$value,
+    source("./src/ui/proxy_get_ui.R", local = TRUE)$value
   )
 ))
